{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 300,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "quay.io/biocontainers/biom-format:2.1.6--py36_0",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "biom-convert.sh"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3746",
                    "inputBinding": {
                        "prefix": "--input-fp"
                    },
                    "id": "#biom-convert.cwl/biom"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as HDF5-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-hdf5"
                    },
                    "id": "#biom-convert.cwl/hdf5"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The observation metadata to include from the input BIOM table file when\ncreating a tsv table file. By default no observation metadata will be\nincluded.\n",
                    "inputBinding": {
                        "prefix": "--header-key"
                    },
                    "id": "#biom-convert.cwl/header_key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as JSON-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-json"
                    },
                    "id": "#biom-convert.cwl/json"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--table-type",
                        "separate": true,
                        "valueFrom": "$(inputs.table_type)"
                    },
                    "id": "#biom-convert.cwl/table_type"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as TSV-formatted (classic) table.",
                    "inputBinding": {
                        "prefix": "--to-tsv"
                    },
                    "id": "#biom-convert.cwl/tsv"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "${ var ext = \"\";\n   if (inputs.json) { ext = \"_json.biom\"; }\n   if (inputs.hdf5) { ext = \"_hdf5.biom\"; }\n   if (inputs.tsv) { ext = \"_tsv.biom\"; }\n   var pre = inputs.biom.nameroot.split('.');\n   pre.pop()\n   return pre.join('.') + ext; }\n",
                    "prefix": "--output-fp"
                },
                {
                    "valueFrom": "--collapsed-observations"
                }
            ],
            "id": "#biom-convert.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${ var ext = \"\";\nif (inputs.json) { ext = \"_json.biom\"; }\nif (inputs.hdf5) { ext = \"_hdf5.biom\"; }\nif (inputs.tsv) { ext = \"_tsv.biom\"; }\nvar pre = inputs.biom.nameroot.split('.');\npre.pop()\nreturn pre.join('.') + ext; }\n"
                    },
                    "id": "#biom-convert.cwl/result"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "visualize using krona",
            "requirements": [
                {
                    "ramMin": 200,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Tab-delimited text file",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#krona.cwl/otu_counts"
                }
            ],
            "baseCommand": "ktImportText",
            "arguments": [
                {
                    "valueFrom": "krona.html",
                    "prefix": "-o"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/html",
                    "outputBinding": {
                        "glob": "*.html"
                    },
                    "id": "#krona.cwl/otu_visualization"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "kronav2.7.1:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "id": "#krona.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "MAPseq v 1.2.3",
            "doc": "sequence read classification tools designed to assign taxonomy and OTU\nclassifications to ribosomal RNA sequences.\nhttps://github.com/jfmrod/MAPseq\n",
            "requirements": [
                {
                    "ramMin": 25000,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster"
                        }
                    ],
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/database"
                },
                {
                    "type": "File",
                    "id": "#mapseq.cwl/prefix"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/sequences"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#mapseq.cwl/taxonomy"
                }
            ],
            "baseCommand": "mapseq",
            "arguments": [
                "-nthreads",
                "8",
                "-tophits",
                "80",
                "-topotus",
                "40",
                "-outfmt",
                "simple"
            ],
            "stdout": "$(inputs.prefix.nameroot)_$(inputs.database.basename).mseq",
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "id": "#mapseq.cwl/classifications",
                    "outputBinding": {
                        "glob": "$(inputs.prefix.nameroot)_$(inputs.database.basename).mseq"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mapseq:latest"
                }
            ],
            "id": "#mapseq.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "mapseq2biom:latest",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "ramMin": 200,
                    "tmpdirMin": 200,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "label": "label to add to the top of the outfile OTU table",
                    "inputBinding": {
                        "prefix": "--label"
                    },
                    "id": "#mapseq2biom.cwl/label"
                },
                {
                    "type": "string",
                    "doc": "the OTU table produced for the taxonomies found in the reference\ndatabases that was used with MAPseq\n",
                    "inputBinding": {
                        "prefix": "--otuTable"
                    },
                    "id": "#mapseq2biom.cwl/otu_table"
                },
                {
                    "type": "File",
                    "label": "the output from the MAPseq that assigns a taxonomy to a sequence",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "inputBinding": {
                        "prefix": "--query"
                    },
                    "id": "#mapseq2biom.cwl/query"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "output NCBI taxids for all databases bar UNITE",
                    "inputBinding": {
                        "prefix": "--taxid"
                    },
                    "id": "#mapseq2biom.cwl/taxid_flag"
                }
            ],
            "baseCommand": [
                "mapseq2biom.pl"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.query.basename).tsv",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "$(inputs.query.basename).txt",
                    "prefix": "--krona"
                },
                {
                    "valueFrom": "$(inputs.query.basename).notaxid.tsv",
                    "prefix": "--notaxidfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "outputBinding": {
                        "glob": "$(inputs.query.basename).tsv"
                    },
                    "id": "#mapseq2biom.cwl/otu_tsv"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3746",
                    "outputBinding": {
                        "glob": "$(inputs.query.basename).notaxid.tsv"
                    },
                    "id": "#mapseq2biom.cwl/otu_tsv_notaxid"
                },
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.query.basename).txt"
                    },
                    "id": "#mapseq2biom.cwl/otu_txt"
                }
            ],
            "id": "#mapseq2biom.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#count_number_lines.cwl/input_file"
                }
            ],
            "baseCommand": [
                "bash"
            ],
            "arguments": [
                {
                    "valueFrom": "expr \\$(cat $(inputs.input_file.path) | wc -l)\n",
                    "prefix": "-c"
                }
            ],
            "stdout": "count",
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "count",
                        "outputEval": "$(Number(self[0].contents))",
                        "loadContents": true
                    },
                    "id": "#count_number_lines.cwl/number"
                }
            ],
            "id": "#count_number_lines.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 16,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#gzip.cwl/uncompressed_file"
                }
            ],
            "baseCommand": [
                "pigz"
            ],
            "arguments": [
                "-p",
                "16",
                "-c"
            ],
            "stdout": "$(inputs.uncompressed_file.basename).gz",
            "outputs": [
                {
                    "type": "File",
                    "id": "#gzip.cwl/compressed_file",
                    "outputBinding": {
                        "glob": "$(inputs.uncompressed_file.basename).gz"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#gzip.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "null",
                                "Directory"
                            ]
                        }
                    ],
                    "id": "#return_directory.cwl/dir_list"
                },
                {
                    "type": "string",
                    "id": "#return_directory.cwl/dir_name"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "null",
                                "File"
                            ]
                        }
                    ],
                    "id": "#return_directory.cwl/file_list"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "id": "#return_directory.cwl/out"
                }
            ],
            "expression": "${\n  var list2 = [];\n  var process;\n  if (inputs.file_list) { process = inputs.file_list } else { process = inputs.dir_list}\n  for (const item in process) {\n      if (process[item] != null) {\n          list2.push(process[item]) }; }\n  return {\"out\": {\n    \"class\": \"Directory\",\n    \"basename\": inputs.dir_name,\n    \"listing\": list2\n    }\n  }; }\n",
            "id": "#return_directory.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "Run taxonomic classification, create OTU table and krona visualisation",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/fasta"
                },
                {
                    "type": "File",
                    "id": "#main/file_for_prefix"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#main/mapseq_ref"
                },
                {
                    "type": "string",
                    "id": "#main/mapseq_taxonomy"
                },
                {
                    "type": "string",
                    "id": "#main/otu_label"
                },
                {
                    "type": "string",
                    "id": "#main/otu_ref"
                },
                {
                    "type": "string",
                    "id": "#main/return_dirname"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "outputSource": "#main/count_lines_mapseq/number",
                    "id": "#main/number_lines_mapseq"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/return_output_dir/out",
                    "id": "#main/out_dir"
                }
            ],
            "steps": [
                {
                    "run": "#mapseq2biom.cwl",
                    "in": [
                        {
                            "source": "#main/otu_label",
                            "id": "#main/classifications_to_otu_counts/label"
                        },
                        {
                            "source": "#main/otu_ref",
                            "id": "#main/classifications_to_otu_counts/otu_table"
                        },
                        {
                            "source": "#main/mapseq/classifications",
                            "id": "#main/classifications_to_otu_counts/query"
                        },
                        {
                            "default": true,
                            "id": "#main/classifications_to_otu_counts/taxid_flag"
                        }
                    ],
                    "out": [
                        "#main/classifications_to_otu_counts/otu_tsv",
                        "#main/classifications_to_otu_counts/otu_txt",
                        "#main/classifications_to_otu_counts/otu_tsv_notaxid"
                    ],
                    "id": "#main/classifications_to_otu_counts"
                },
                {
                    "run": "#gzip.cwl",
                    "in": [
                        {
                            "source": "#main/mapseq/classifications",
                            "id": "#main/compress_mapseq/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#main/compress_mapseq/compressed_file"
                    ],
                    "label": "gzip mapseq output",
                    "id": "#main/compress_mapseq"
                },
                {
                    "run": "#count_number_lines.cwl",
                    "in": [
                        {
                            "source": "#main/mapseq/classifications",
                            "id": "#main/count_lines_mapseq/input_file"
                        }
                    ],
                    "out": [
                        "#main/count_lines_mapseq/number"
                    ],
                    "id": "#main/count_lines_mapseq"
                },
                {
                    "when": "$(inputs.count > 2)",
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#main/classifications_to_otu_counts/otu_tsv_notaxid",
                            "id": "#main/counts_to_hdf5/biom"
                        },
                        {
                            "source": "#main/count_lines_mapseq/number",
                            "id": "#main/counts_to_hdf5/count"
                        },
                        {
                            "default": true,
                            "id": "#main/counts_to_hdf5/hdf5"
                        },
                        {
                            "default": "OTU table",
                            "id": "#main/counts_to_hdf5/table_type"
                        }
                    ],
                    "out": [
                        "#main/counts_to_hdf5/result"
                    ],
                    "id": "#main/counts_to_hdf5"
                },
                {
                    "when": "$(inputs.count > 2)",
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#main/classifications_to_otu_counts/otu_tsv_notaxid",
                            "id": "#main/counts_to_json/biom"
                        },
                        {
                            "source": "#main/count_lines_mapseq/number",
                            "id": "#main/counts_to_json/count"
                        },
                        {
                            "default": true,
                            "id": "#main/counts_to_json/json"
                        },
                        {
                            "default": "OTU table",
                            "id": "#main/counts_to_json/table_type"
                        }
                    ],
                    "out": [
                        "#main/counts_to_json/result"
                    ],
                    "id": "#main/counts_to_json"
                },
                {
                    "run": "#mapseq.cwl",
                    "in": [
                        {
                            "source": "#main/mapseq_ref",
                            "id": "#main/mapseq/database"
                        },
                        {
                            "source": "#main/file_for_prefix",
                            "id": "#main/mapseq/prefix"
                        },
                        {
                            "source": "#main/fasta",
                            "id": "#main/mapseq/sequences"
                        },
                        {
                            "source": "#main/mapseq_taxonomy",
                            "id": "#main/mapseq/taxonomy"
                        }
                    ],
                    "out": [
                        "#main/mapseq/classifications"
                    ],
                    "id": "#main/mapseq"
                },
                {
                    "when": "$(inputs.count > 2)",
                    "run": "#return_directory.cwl",
                    "in": [
                        {
                            "source": "#main/count_lines_mapseq/number",
                            "id": "#main/return_output_dir/count"
                        },
                        {
                            "source": "#main/return_dirname",
                            "id": "#main/return_output_dir/dir_name"
                        },
                        {
                            "source": [
                                "#main/compress_mapseq/compressed_file",
                                "#main/classifications_to_otu_counts/otu_tsv",
                                "#main/classifications_to_otu_counts/otu_txt",
                                "#main/visualize_otu_counts/otu_visualization",
                                "#main/counts_to_hdf5/result",
                                "#main/counts_to_json/result"
                            ],
                            "id": "#main/return_output_dir/file_list"
                        }
                    ],
                    "out": [
                        "#main/return_output_dir/out"
                    ],
                    "label": "return all files in one folder",
                    "id": "#main/return_output_dir"
                },
                {
                    "run": "#krona.cwl",
                    "in": [
                        {
                            "source": "#main/classifications_to_otu_counts/otu_txt",
                            "id": "#main/visualize_otu_counts/otu_counts"
                        }
                    ],
                    "out": [
                        "#main/visualize_otu_counts/otu_visualization"
                    ],
                    "id": "#main/visualize_otu_counts"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.2",
    "$schemas": [
        "http://edamontology.org/EDAM_1.16.owl",
        "https://schema.org/version/latest/schema.rdf",
        "https://schema.org/version/latest/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
